# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.account_connections_api import AccountConnectionsApi


class TestAccountConnectionsApi(unittest.TestCase):
    """AccountConnectionsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.account_connections_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_delete_account_connection(self, m) -> None:
        """Test case for delete_account_connection

        Delete an account's connection
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.delete_account_connection(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_account_connections(self, m) -> None:
        """Test case for list_account_connections

        List account's connections
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.list_account_connections(
                "uuid_example",
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_banks(self, m) -> None:
        """Test case for list_banks

        List available bank connections
        """
        path = urljoin("https://api.accounting.sh", "/accounts/{uuid}/connect/banks")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.account_connections_api.list_banks(
                "uuid_example",
                "country_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class NotificationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def list_notification_preferences(
        self,
        notification: str,
    ) -> Any | None:
        """List notification preferences


        :param notification: The notification name (required)
        :type notification: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/notifications/preferences/{notification}"
        query_params = {}
        kwargs = {"files": {}, "data": {}, "json": {}}

        if notification is not None:
            path = path.replace("{" + "notification" + "}", notification)

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def list_notifications(
        self,
        fields: str = None,
        page: str = None,
        per_page: str = None,
    ) -> Any | None:
        """List company's notifications


        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/notifications"
        query_params = {}
        kwargs = {"files": {}, "data": {}, "json": {}}

        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)

    def send_notification(
        self,
        send_notification_request: dict,
    ) -> Any | None:
        """Send a notification


        :param send_notification_request: (required)
        :type send_notification_request: SendNotificationRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/notifications/send"
        query_params = {}
        kwargs = {"files": {}, "data": {}, "json": {}}

        if send_notification_request is not None:
            kwargs["json"] = send_notification_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="POST", path=path, **kwargs)

    def update_notification_preferences(
        self,
        notification: str,
        update_notification_preferences_request: dict,
    ) -> Any | None:
        """Update notification preferences


        :param notification: The notification name (required)
        :type notification: str
        :param update_notification_preferences_request: (required)
        :type update_notification_preferences_request: UpdateNotificationPreferencesRequest
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/notifications/preferences/{notification}"
        query_params = {}
        kwargs = {"files": {}, "data": {}, "json": {}}

        if notification is not None:
            path = path.replace("{" + "notification" + "}", notification)
        if update_notification_preferences_request is not None:
            kwargs["json"] = update_notification_preferences_request

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="PUT", path=path, **kwargs)



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.webhooks_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_webhook(self, m) -> None:
        """Test case for add_webhook

        Add a webhook
        """
        path = urljoin("https://api.accounting.sh", "/webhooks")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.webhooks_api.add_webhook(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_webhook(self, m) -> None:
        """Test case for delete_webhook

        Delete a webhook
        """
        path = urljoin("https://api.accounting.sh", "/webhooks/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.webhooks_api.delete_webhook(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_webhook(self, m) -> None:
        """Test case for get_webhook

        Get a webhook
        """
        path = urljoin("https://api.accounting.sh", "/webhooks/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.webhooks_api.get_webhook(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_webhook_history(self, m) -> None:
        """Test case for get_webhook_history

        Get webhook's history
        """
        path = urljoin("https://api.accounting.sh", "/webhooks/{uuid}/history")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.webhooks_api.get_webhook_history(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_webhook_events(self, m) -> None:
        """Test case for list_webhook_events

        List available webhook events
        """
        path = urljoin("https://api.accounting.sh", "/webhooks/events")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.webhooks_api.list_webhook_events() is not None

    @requests_mock.Mocker()
    def test_list_webhooks(self, m) -> None:
        """Test case for list_webhooks

        List company's webhooks
        """
        path = urljoin("https://api.accounting.sh", "/webhooks")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.webhooks_api.list_webhooks(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_webhook(self, m) -> None:
        """Test case for update_webhook

        Update a webhook
        """
        path = urljoin("https://api.accounting.sh", "/webhooks/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.webhooks_api.update_webhook(
                {},
                "uuid_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.expense_reports_api import ExpenseReportsApi


class TestExpenseReportsApi(unittest.TestCase):
    """ExpenseReportsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.expense_reports_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_expense_report(self, m) -> None:
        """Test case for add_expense_report

        Add an expense report
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.add_expense_report(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_expense_report(self, m) -> None:
        """Test case for delete_expense_report

        Delete an expense report
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.delete_expense_report(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_expense_report_o_auth_login(self, m) -> None:
        """Test case for expense_report_o_auth_login

        OAuth Login
        """
        path = urljoin(
            "https://api.accounting.sh", "/expenses/expense-reports/login/{method}"
        )
        path = path.replace("{" + "method" + "}", "method_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.expense_report_o_auth_login(
                "method_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_expense_report(self, m) -> None:
        """Test case for get_expense_report

        Get an expense report
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.get_expense_report(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_expense_report_account(self, m) -> None:
        """Test case for get_expense_report_account

        Get the currently connected expense report user details
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/me")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.expense_reports_api.get_expense_report_account() is not None

    @requests_mock.Mocker()
    def test_get_expense_report_user(self, m) -> None:
        """Test case for get_expense_report_user

        Get an user details
        """
        path = urljoin(
            "https://api.accounting.sh", "/expenses/expense-reports/users/{uuid}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.get_expense_report_user(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_expense_reports(self, m) -> None:
        """Test case for list_expense_reports

        List company's expense reports.
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.list_expense_reports(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_send_expense_report_login_email(self, m) -> None:
        """Test case for send_expense_report_login_email

        Request login email
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/login")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.send_expense_report_login_email(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_expense_report(self, m) -> None:
        """Test case for update_expense_report

        Update an expense report
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.update_expense_report(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_expense_report_account(self, m) -> None:
        """Test case for update_expense_report_account

        Update the currently connected expense report user
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/me")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.update_expense_report_account(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_expense_report_settings(self, m) -> None:
        """Test case for update_expense_report_settings

        Retrieve company settings for expense reports
        """
        path = urljoin(
            "https://api.accounting.sh", "/expenses/expense-reports/settings"
        )
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.update_expense_report_settings(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_verify_expense_report_settings(self, m) -> None:
        """Test case for verify_expense_report_settings

        Verify expense reports settings
        """
        path = urljoin("https://api.accounting.sh", "/expenses/expense-reports/verify")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.expense_reports_api.verify_expense_report_settings(
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.revenues_api import RevenuesApi


class TestRevenuesApi(unittest.TestCase):
    """RevenuesApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.revenues_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_revenue(self, m) -> None:
        """Test case for add_revenue

        Add a revenue
        """
        path = urljoin("https://api.accounting.sh", "/incomes/revenues")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.revenues_api.add_revenue(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_revenue(self, m) -> None:
        """Test case for delete_revenue

        Delete a revenue
        """
        path = urljoin("https://api.accounting.sh", "/incomes/revenues/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.revenues_api.delete_revenue(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_revenue(self, m) -> None:
        """Test case for get_revenue

        Get a revenue
        """
        path = urljoin("https://api.accounting.sh", "/incomes/revenues/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.revenues_api.get_revenue(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_revenues(self, m) -> None:
        """Test case for list_revenues

        List company's revenues
        """
        path = urljoin("https://api.accounting.sh", "/incomes/revenues")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.revenues_api.list_revenues(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_revenue(self, m) -> None:
        """Test case for update_revenue

        Update a revenue
        """
        path = urljoin("https://api.accounting.sh", "/incomes/revenues/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.revenues_api.update_revenue(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.contacts_api import ContactsApi


class TestContactsApi(unittest.TestCase):
    """ContactsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.contacts_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_contact(self, m) -> None:
        """Test case for add_contact

        Create a new contact
        """
        path = urljoin("https://api.accounting.sh", "/contacts")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.add_contact(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_contact(self, m) -> None:
        """Test case for delete_contact

        Delete a contact
        """
        path = urljoin("https://api.accounting.sh", "/contacts/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.delete_contact(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_contact(self, m) -> None:
        """Test case for get_contact

        Retrieve a contact
        """
        path = urljoin("https://api.accounting.sh", "/contacts/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.get_contact(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_contact_bills(self, m) -> None:
        """Test case for list_contact_bills

        List a contact's bills
        """
        path = urljoin("https://api.accounting.sh", "/contacts/{uuid}/bills")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.list_contact_bills(
                "uuid_example",
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_contact_invoices(self, m) -> None:
        """Test case for list_contact_invoices

        List a contact's invoices
        """
        path = urljoin("https://api.accounting.sh", "/contacts/{uuid}/invoices")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.list_contact_invoices(
                "uuid_example",
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_contacts(self, m) -> None:
        """Test case for list_contacts

        List company's contacts
        """
        path = urljoin("https://api.accounting.sh", "/contacts")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.list_contacts(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_contact(self, m) -> None:
        """Test case for update_contact

        Update a contact
        """
        path = urljoin("https://api.accounting.sh", "/contact/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.contacts_api.update_contact(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.bills_api import BillsApi


class TestBillsApi(unittest.TestCase):
    """BillsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.bills_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_bill(self, m) -> None:
        """Test case for add_bill

        Add a bill
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.add_bill(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_add_bill_payment(self, m) -> None:
        """Test case for add_bill_payment

        Add a bill payment
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills/{uuid}/payments")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.add_bill_payment(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_bill(self, m) -> None:
        """Test case for delete_bill

        Delete a bill
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.delete_bill(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_bill(self, m) -> None:
        """Test case for get_bill

        Get a bill
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.get_bill(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_bill_document(self, m) -> None:
        """Test case for get_bill_document

        Get a bill in PDF
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills/{uuid}/document")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.get_bill_document(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_bills(self, m) -> None:
        """Test case for list_bills

        List company's bills
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.list_bills(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_bill(self, m) -> None:
        """Test case for update_bill

        Update a bill
        """
        path = urljoin("https://api.accounting.sh", "/expenses/bills/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.update_bill(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_bill_payment(self, m) -> None:
        """Test case for update_bill_payment

        Update a bill payment
        """
        path = urljoin(
            "https://api.accounting.sh", "/expenses/bills/{uuid}/payments/{payment}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "payment" + "}", "payment_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.bills_api.update_bill_payment(
                "uuid_example",
                "payment_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.companies_api import CompaniesApi


class TestCompaniesApi(unittest.TestCase):
    """CompaniesApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.companies_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_company(self, m) -> None:
        """Test case for add_company

        Add a company
        """
        path = urljoin("https://api.accounting.sh", "/companies")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.add_company(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_company(self, m) -> None:
        """Test case for delete_company

        Delete a company
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.delete_company(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_company(self, m) -> None:
        """Test case for get_company

        Get a company
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.get_company(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_company_customization(self, m) -> None:
        """Test case for get_company_customization

        Get a company's customization parameters
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}/customization")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.get_company_customization(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_company_feature_set(self, m) -> None:
        """Test case for get_company_feature_set

        List a company's feature set
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}/features")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.get_company_feature_set(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_companies(self, m) -> None:
        """Test case for list_companies

        List companies on this instance
        """
        path = urljoin("https://api.accounting.sh", "/companies")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.list_companies(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_company(self, m) -> None:
        """Test case for update_company

        Update a company
        """
        path = urljoin("https://api.accounting.sh", "/companies/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.companies_api.update_company(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.rossum_api import RossumApi


class TestRossumApi(unittest.TestCase):
    """RossumApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.rossum_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_list_reviews(self, m) -> None:
        """Test case for list_reviews

        List documents to be reviewes
        """
        path = urljoin("https://api.accounting.sh", "/external/rossum/reviews")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.rossum_api.list_reviews(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.invoices_api import InvoicesApi


class TestInvoicesApi(unittest.TestCase):
    """InvoicesApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.invoices_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_invoice(self, m) -> None:
        """Test case for add_invoice

        Add an invoice
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.add_invoice(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_add_invoice_payment(self, m) -> None:
        """Test case for add_invoice_payment

        Add an invoice payment
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices/{uuid}/payments")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.add_invoice_payment(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_invoice(self, m) -> None:
        """Test case for delete_invoice

        Delete an invoice
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.delete_invoice(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_invoice(self, m) -> None:
        """Test case for get_invoice

        Get an invoice
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.get_invoice(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_invoice_document(self, m) -> None:
        """Test case for get_invoice_document

        Get an invoice in PDF
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices/{uuid}/document")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.get_invoice_document(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_invoices(self, m) -> None:
        """Test case for list_invoices

        List company's invoices
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.list_invoices(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_unpaid_invoices(self, m) -> None:
        """Test case for list_unpaid_invoices

        List company's unpaid invoices
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices/unpaid")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.invoices_api.list_unpaid_invoices() is not None

    @requests_mock.Mocker()
    def test_update_invoice(self, m) -> None:
        """Test case for update_invoice

        Update an invoice
        """
        path = urljoin("https://api.accounting.sh", "/incomes/invoices/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.update_invoice(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_invoice_payment(self, m) -> None:
        """Test case for update_invoice_payment

        Update an invoice payment
        """
        path = urljoin(
            "https://api.accounting.sh", "/incomes/invoices/{uuid}/payments/{payment}"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        path = path.replace("{" + "payment" + "}", "payment_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.invoices_api.update_invoice_payment(
                "uuid_example",
                "payment_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.o_auth_config_api import OAuthConfigApi


class TestOAuthConfigApi(unittest.TestCase):
    """OAuthConfigApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.o_auth_config_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_o_auth_configuration(self, m) -> None:
        """Test case for add_o_auth_configuration

        Add an OAuth configuration
        """
        path = urljoin("https://api.accounting.sh", "/oauth")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.o_auth_config_api.add_o_auth_configuration(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_o_auth_configuration(self, m) -> None:
        """Test case for delete_o_auth_configuration

        Delete an oauth configuration
        """
        path = urljoin("https://api.accounting.sh", "/oauth/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.o_auth_config_api.delete_o_auth_configuration(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_o_auth_configuration(self, m) -> None:
        """Test case for get_o_auth_configuration

        Get an OAuth configuration
        """
        path = urljoin("https://api.accounting.sh", "/oauth/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.o_auth_config_api.get_o_auth_configuration(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_o_auth_configurations(self, m) -> None:
        """Test case for list_o_auth_configurations

        List company's oauth configurations
        """
        path = urljoin("https://api.accounting.sh", "/oauth")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.o_auth_config_api.list_o_auth_configurations(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_providers(self, m) -> None:
        """Test case for list_providers

        List available providers
        """
        path = urljoin("https://api.accounting.sh", "/oauth/providers")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.o_auth_config_api.list_providers() is not None

    @requests_mock.Mocker()
    def test_update_o_auth_configuration(self, m) -> None:
        """Test case for update_o_auth_configuration

        Update an oauth configuration
        """
        path = urljoin("https://api.accounting.sh", "/oauth/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.o_auth_config_api.update_o_auth_configuration(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



class ApiException(Exception):
    def __init__(self, status_code, body, headers):
        self.status_code = status_code
        self.body = body
        self.headers = headers

        super(ApiException, self).__init__(str(status_code) + " - " + body)



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.export_api import ExportApi


class TestExportApi(unittest.TestCase):
    """ExportApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.export_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_list_exports(self, m) -> None:
        """Test case for list_exports

        List company's exports
        """
        path = urljoin("https://api.accounting.sh", "/export")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.export_api.list_exports(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_request_export(self, m) -> None:
        """Test case for request_export

        Request an export
        """
        path = urljoin("https://api.accounting.sh", "/export")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.export_api.request_export(
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.documents_api import DocumentsApi


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.documents_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_cancel_review(self, m) -> None:
        """Test case for cancel_review

        Cancel document review
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}/review")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.cancel_review(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_document(self, m) -> None:
        """Test case for delete_document

        Delete a document
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.delete_document(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_document(self, m) -> None:
        """Test case for get_document

        Get a document
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.get_document(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_documents(self, m) -> None:
        """Test case for list_documents

        List company's documents
        """
        path = urljoin("https://api.accounting.sh", "/documents")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.list_documents(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_process_document(self, m) -> None:
        """Test case for process_document

        Process a document
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}/process")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.process_document(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_review_url(self, m) -> None:
        """Test case for review_url

        Get url to review a document
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}/review")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.review_url(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_document(self, m) -> None:
        """Test case for update_document

        Update a document
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.update_document(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_upload_document(self, m) -> None:
        """Test case for upload_document

        Upload a document
        """
        path = urljoin("https://api.accounting.sh", "/documents")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.upload_document(
                "name_example",
                None,
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_view_document(self, m) -> None:
        """Test case for view_document

        View a document
        """
        path = urljoin("https://api.accounting.sh", "/documents/{uuid}/view")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.documents_api.view_document(
                "uuid_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from json import dumps
from typing import Any, Dict, List, Optional, Tuple, Union
from urllib.parse import urlencode

from typing_extensions import Annotated


class LogsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, accounting) -> None:
        self.accounting = accounting

    def logs(
        self,
        fields: str = None,
        page: str = None,
        per_page: str = None,
        channel: str = None,
        level: str = None,
        resource: str = None,
        before: str = None,
        after: str = None,
        format: str = None,
    ) -> Any | None:
        """List company's logs


        :param fields: A comma separated list of fields requested in the response
        :type fields: str
        :param page: The response page
        :type page: str
        :param per_page: The number of items per page
        :type per_page: str
        :param channel: The channel to retrieve the logs from
        :type channel: str
        :param level: The log level to retrieve
        :type level: str
        :param resource: Retrive logs linked to that resource
        :type resource: str
        :param before: Retrive logs before the provided date
        :type before: str
        :param after: Retrive logs after the provided date
        :type after: str
        :param format: In which format to retrieve the logs, available: json or txt
        :type format: str
        :return: Returns a dict containing the API Response.
        """  # noqa: E501

        path = "/logs"
        query_params = {}
        kwargs = {"files": {}, "data": {}, "json": {}}

        if fields is not None:

            query_params["fields"] = fields

        if page is not None:

            query_params["page"] = page

        if per_page is not None:

            query_params["per_page"] = per_page

        if channel is not None:

            query_params["channel"] = channel

        if level is not None:

            query_params["level"] = level

        if resource is not None:

            query_params["resource"] = resource

        if before is not None:

            query_params["before"] = before

        if after is not None:

            query_params["after"] = after

        if format is not None:

            query_params["format"] = format

        if len(kwargs["data"]) == 0:
            del kwargs["data"]
        if len(kwargs["json"]) == 0:
            del kwargs["json"]
        if len(kwargs["files"]) == 0:
            del kwargs["files"]

        if len(query_params) > 0:
            query_params.update(
                {
                    k: dumps(v)
                    for k, v in query_params.items()
                    if isinstance(v, (bool, dict))
                }
            )
            path = path + "?" + urlencode(query_params, doseq=True)
        return self.accounting.request(method="GET", path=path, **kwargs)



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import find_packages, setup  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "accounting-sh"
VERSION = "0.2.0"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "requests >= 2.32.3",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Accounting API",
    author="STAN-TAB CORP. LTD",
    author_email="support@stantabcorp.com",
    url="",
    keywords=["OpenAPI", "Accounting API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test"]),
    include_package_data=True,
    license="Apache-2.0",
    long_description_content_type="text/markdown",
    long_description="""\
    ### Welcome to STAN-TAB CORP&#39;s Accounting Software API documentation.  This page contains the documentation and reference of the Accounting API.  &gt; **NEW**: You can now use this API by registering on https://my.stantabcorp.com !  **Status Page:** [https://status.stantabcorp.net/status/accounting](https://status.stantabcorp.net/status/accounting)  #### Rate limits  The API is rate-limited based on IP addresses. By default you can make 3 request every 180 seconds (3 minutes). If you need an higher limit, please contact us with the list of ip address to whitelist.  #### Audit  You can add an arbitrary comment to every request that will be logged by adding the: &#x60;X-Audit-Comment&#x60; header with the comment you want to add to your requests.  #### Good to know  The way this API is designed, some webhook event are sent before the event happened and may be fired even if the action failed.   Webhooks events may be sent out of order. 
    """,  # noqa: E501
)



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.categories_api import CategoriesApi


class TestCategoriesApi(unittest.TestCase):
    """CategoriesApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.categories_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_category(self, m) -> None:
        """Test case for add_category

        Add a category
        """
        path = urljoin("https://api.accounting.sh", "/categories")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.categories_api.add_category(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_category(self, m) -> None:
        """Test case for delete_category

        Delete a category
        """
        path = urljoin("https://api.accounting.sh", "/categories/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.categories_api.delete_category(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_category(self, m) -> None:
        """Test case for get_category

        Get a category
        """
        path = urljoin("https://api.accounting.sh", "/categories/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.categories_api.get_category(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_categories(self, m) -> None:
        """Test case for list_categories

        List company's categories
        """
        path = urljoin("https://api.accounting.sh", "/categories")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.categories_api.list_categories(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_update_category(self, m) -> None:
        """Test case for update_category

        Update a category
        """
        path = urljoin("https://api.accounting.sh", "/categories/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.categories_api.update_category(
                "uuid_example",
                {},
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.company_statistics_api import CompanyStatisticsApi


class TestCompanyStatisticsApi(unittest.TestCase):
    """CompanyStatisticsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.company_statistics_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_get_statistics(self, m) -> None:
        """Test case for get_statistics

        Get company's statistic
        """
        path = urljoin(
            "https://api.accounting.sh", "/companies/{uuid}/statistics/period"
        )
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.company_statistics_api.get_statistics(
                "uuid_example",
                "start_example",
                "end_example",
            )
            is not None
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Accounting API


    The version of the OpenAPI document: 7.3.10
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
from urllib.parse import urljoin

import requests_mock

from accounting_sh.accounting import Accounting
from accounting_sh.api.credentials_api import CredentialsApi


class TestCredentialsApi(unittest.TestCase):
    """CredentialsApi unit test stubs"""

    """
    def setUp(self) -> None:
        accounting = Accounting("fake-token")
        self.api = accounting.credentials_api

    def tearDown(self) -> None:
        pass
    """

    @requests_mock.Mocker()
    def test_add_credential(self, m) -> None:
        """Test case for add_credential

        Add a credential
        """
        path = urljoin("https://api.accounting.sh", "/credentials")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.credentials_api.add_credential(
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_delete_credential(self, m) -> None:
        """Test case for delete_credential

        Delete a credential
        """
        path = urljoin("https://api.accounting.sh", "/credentials/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("DELETE", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.credentials_api.delete_credential(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_get_credential(self, m) -> None:
        """Test case for get_credential

        Get a credential
        """
        path = urljoin("https://api.accounting.sh", "/credentials/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.credentials_api.get_credential(
                "uuid_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_credentials(self, m) -> None:
        """Test case for list_credentials

        List company's credentials
        """
        path = urljoin("https://api.accounting.sh", "/credentials")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.credentials_api.list_credentials(
                "fields_example",
                "page_example",
                "per_page_example",
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_list_permissions(self, m) -> None:
        """Test case for list_permissions

        List available permissions
        """
        path = urljoin("https://api.accounting.sh", "/credentials/permissions")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.credentials_api.list_permissions() is not None

    @requests_mock.Mocker()
    def test_me(self, m) -> None:
        """Test case for me

        Get current credential informations
        """
        path = urljoin("https://api.accounting.sh", "/me")
        m.request("GET", path)
        accounting = Accounting("fake-token")
        assert accounting.credentials_api.me() is not None

    @requests_mock.Mocker()
    def test_update_credential(self, m) -> None:
        """Test case for update_credential

        Update a credential
        """
        path = urljoin("https://api.accounting.sh", "/credentials/{uuid}")
        path = path.replace("{" + "uuid" + "}", "uuid_example")
        m.request("PUT", path)
        accounting = Accounting("fake-token")
        assert (
            accounting.credentials_api.update_credential(
                "uuid_example",
                {},
            )
            is not None
        )

    @requests_mock.Mocker()
    def test_userveria(self, m) -> None:
        """Test case for userveria

        Exchange a my stantabcorp (userveria) token for an Accounting Token
        """
        path = urljoin("https://api.accounting.sh", "/userveria")
        m.request("POST", path)
        accounting = Accounting("fake-token")
        assert accounting.credentials_api.userveria() is not None


if __name__ == "__main__":
    unittest.main()
